searchData={"items":[{"type":"module","title":"Split","doc":"The Split.io Elixir thin client.\n\nThis module provides a simple API to interact with the Split.io service\nvia the [Split Daemon (splitd)](https://help.split.io/hc/en-us/articles/18305269686157-Split-Daemon-splitd).","ref":"Split.html"},{"type":"module","title":"Adding Split to Your Supervision Tree - Split","doc":"The most basic approach is to add `Split` as a child of your application's\ntop-most supervisor, i.e. `lib/my_app/application.ex`.\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # ... other children ...\n      {Split, [socket_path: \"/var/run/split.sock\"]}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nYou can also start `Split` dynamically by calling `Split.Supervisor.start_link/1`:\n\n```elixir\nSplit.Supervisor.start_link(opts)\n```","ref":"Split.html#module-adding-split-to-your-supervision-tree"},{"type":"module","title":"Options - Split","doc":"`Split` takes a number of keyword arguments as options when starting. The following options are available:\n\n- `:socket_path`: **REQUIRED** The path to the splitd socket file. For example `/var/run/splitd.sock`.\n- `:pool_size`: **OPTIONAL** The size of the pool of connections to the splitd daemon. Default is the number of online schedulers in the Erlang VM (See: https://www.erlang.org/doc/apps/erts/erl_cmd.html).\n- `:connect_timeout`: **OPTIONAL** The timeout in milliseconds to connect to the splitd daemon. Default is `1000`.","ref":"Split.html#module-options"},{"type":"module","title":"Using the API - Split","doc":"Once you have started Split, you are ready to start interacting with the Split.io splitd's daemon to access feature flags and configurations.\n\n```elixir\nSplit.get_treatment(\"user_key\", \"feature_name\")\n```","ref":"Split.html#module-using-the-api"},{"type":"function","title":"Split.child_spec/1","doc":"Builds a child specification to use in a Supervisor.\n\nNormally not called directly by your code. Instead, it will be\ncalled by your application's Supervisor once you add `Split`\nto its supervision tree.","ref":"Split.html#child_spec/1"},{"type":"function","title":"Split.get_treatment/3","doc":"","ref":"Split.html#get_treatment/3"},{"type":"function","title":"Split.get_treatment_with_config/3","doc":"","ref":"Split.html#get_treatment_with_config/3"},{"type":"function","title":"Split.get_treatments/3","doc":"","ref":"Split.html#get_treatments/3"},{"type":"function","title":"Split.get_treatments_by_flag_set/3","doc":"","ref":"Split.html#get_treatments_by_flag_set/3"},{"type":"function","title":"Split.get_treatments_by_flag_sets/3","doc":"","ref":"Split.html#get_treatments_by_flag_sets/3"},{"type":"function","title":"Split.get_treatments_with_config/3","doc":"","ref":"Split.html#get_treatments_with_config/3"},{"type":"function","title":"Split.get_treatments_with_config_by_flag_set/3","doc":"","ref":"Split.html#get_treatments_with_config_by_flag_set/3"},{"type":"function","title":"Split.get_treatments_with_config_by_flag_sets/3","doc":"","ref":"Split.html#get_treatments_with_config_by_flag_sets/3"},{"type":"function","title":"Split.split/1","doc":"","ref":"Split.html#split/1"},{"type":"function","title":"Split.split_names/0","doc":"","ref":"Split.html#split_names/0"},{"type":"function","title":"Split.splits/0","doc":"","ref":"Split.html#splits/0"},{"type":"function","title":"Split.track/5","doc":"","ref":"Split.html#track/5"},{"type":"type","title":"Split.option/0","doc":"An option that can be provided when starting `Split`.","ref":"Split.html#t:option/0"},{"type":"type","title":"Split.options/0","doc":"","ref":"Split.html#t:options/0"},{"type":"type","title":"Split.split_key/0","doc":"","ref":"Split.html#t:split_key/0"},{"type":"module","title":"Split.Impression","doc":"","ref":"Split.Impression.html"},{"type":"function","title":"Split.Impression.build_from_daemon_response/4","doc":"","ref":"Split.Impression.html#build_from_daemon_response/4"},{"type":"type","title":"Split.Impression.t/0","doc":"","ref":"Split.Impression.html#t:t/0"},{"type":"module","title":"Split.RPC.Encoder","doc":"Encoder module for Splitd.","ref":"Split.RPC.Encoder.html"},{"type":"function","title":"Split.RPC.Encoder.encode/1","doc":"Encodes an RPC message using Msgpax and appends the size of the encoded message in bytes.","ref":"Split.RPC.Encoder.html#encode/1"},{"type":"function","title":"Examples - Split.RPC.Encoder.encode/1","doc":"iex> message = Message.split(\"test_split\")\n    ...> [_size, encoded] = Encoder.encode(message)\n    ...> Msgpax.unpack!(encoded)\n\n    %{\"a\" => [\"test_split\"], \"o\" => 161, \"v\" => 1}","ref":"Split.RPC.Encoder.html#encode/1-examples"},{"type":"module","title":"Split.RPC.Fallback","doc":"This module is used to provide default values for all Splitd RPC calls.\n\nWhen a call to Splitd fails, the fallback values are returned instead of the error received from the socket.","ref":"Split.RPC.Fallback.html"},{"type":"function","title":"Split.RPC.Fallback.fallback/1","doc":"Provides a default value for the given RPC message.","ref":"Split.RPC.Fallback.html#fallback/1"},{"type":"function","title":"Examples - Split.RPC.Fallback.fallback/1","doc":"iex> Fallback.fallback(%Message{o: 0x11})\n    %Impression{treatment: \"control\", label: \"exception\"}\n\n    iex> Fallback.fallback(%Message{o: 0x13})\n    %Impression{treatment: \"control\", label: \"exception\", config: nil}\n\n    iex> Fallback.fallback(%Message{\n    ...>   o: 0x12,\n    ...>   a: [\"user_key\", \"bucketing_key\", [\"feature_1\", \"feature_2\"], %{}]\n    ...> })\n    %{\n      \"feature_1\" => %Impression{treatment: \"control\", label: \"exception\"},\n      \"feature_2\" => %Impression{treatment: \"control\", label: \"exception\"}\n    }\n\n    iex> Fallback.fallback(%Message{o: 0x14, a: [\"user_key\", \"bucketing_key\", [\"feature_a\"], %{}]})\n    %{\"feature_a\" => %Impression{treatment: \"control\", label: \"exception\", config: nil}}\n\n    iex> Fallback.fallback(%Message{o: 0xA1})\n    nil\n\n    iex> Fallback.fallback(%Message{o: 0xA2})\n    []\n\n    iex> Fallback.fallback(%Message{o: 0xA0})\n    []\n\n    iex> Fallback.fallback(%Message{o: 0x80})\n    false","ref":"Split.RPC.Fallback.html#fallback/1-examples"},{"type":"module","title":"Split.RPC.Message","doc":"","ref":"Split.RPC.Message.html"},{"type":"function","title":"Split.RPC.Message.__struct__/0","doc":"Represents an RPC message to be sent to splitd.","ref":"Split.RPC.Message.html#__struct__/0"},{"type":"function","title":"Split.RPC.Message.get_treatment/1","doc":"Builds a message to get the treatment for a specific feature flag.","ref":"Split.RPC.Message.html#get_treatment/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatment/1","doc":"iex> Message.get_treatment(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_name: \"feature_name\"\n    ...> )\n    %Message{a: [\"user_key\", \"bucketing_key\", \"feature_name\", %{}], o: 17, v: 1}\n\n    iex> Message.get_treatment(key: \"user_key\", feature_name: \"feature_name\")\n    %Message{a: [\"user_key\", nil, \"feature_name\", %{}], o: 17, v: 1}","ref":"Split.RPC.Message.html#get_treatment/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatment_with_config/1","doc":"Builds a message to get the treatment for a specific feature flag with configuration.","ref":"Split.RPC.Message.html#get_treatment_with_config/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatment_with_config/1","doc":"iex> Message.get_treatment_with_config(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_name: \"feature_name\"\n    ...> )\n    %Message{a: [\"user_key\", \"bucketing_key\", \"feature_name\", %{}], o: 19, v: 1}\n\n    iex> Message.get_treatment_with_config(\n    ...>   key: \"user_key\",\n    ...>   feature_name: \"feature_name\"\n    ...> )\n    %Message{a: [\"user_key\", nil, \"feature_name\", %{}], o: 19, v: 1}","ref":"Split.RPC.Message.html#get_treatment_with_config/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatments/1","doc":"Builds a message to get the treatments for multiple feature flags.","ref":"Split.RPC.Message.html#get_treatments/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatments/1","doc":"iex> Message.get_treatments(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_names: [\"feature_name1\", \"feature_name2\"]\n    ...> )\n    %Message{\n      a: [\"user_key\", \"bucketing_key\", [\"feature_name1\", \"feature_name2\"], %{}],\n      o: 18,\n      v: 1\n    }\n\n    iex> Message.get_treatments(\n    ...>   key: \"user_key\",\n    ...>   feature_names: [\"feature_name1\", \"feature_name2\"]\n    ...> )\n    %Message{a: [\"user_key\", nil, [\"feature_name1\", \"feature_name2\"], %{}], o: 18, v: 1}","ref":"Split.RPC.Message.html#get_treatments/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatments_by_flag_set/1","doc":"Builds a message to get the treatments for a flag set.","ref":"Split.RPC.Message.html#get_treatments_by_flag_set/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatments_by_flag_set/1","doc":"iex> Message.get_treatments_by_flag_set(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_name: \"flag_set_name\"\n    ...> )\n    %Message{\n      a: [\"user_key\", \"bucketing_key\", \"flag_set_name\", %{}],\n      o: 21,\n      v: 1\n    }\n\n    iex> Message.get_treatments_by_flag_set(\n    ...>   key: \"user_key\",\n    ...>   feature_name: \"flag_set_name\"\n    ...> )\n    %Message{a: [\"user_key\", nil, \"flag_set_name\", %{}], o: 21, v: 1}","ref":"Split.RPC.Message.html#get_treatments_by_flag_set/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatments_by_flag_sets/1","doc":"Builds a message to get the treatments for multiple flag sets.","ref":"Split.RPC.Message.html#get_treatments_by_flag_sets/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatments_by_flag_sets/1","doc":"iex> Message.get_treatments_by_flag_sets(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_names: [\"flag_set_name1\", \"flag_set_name2\"]\n    ...> )\n    %Message{\n      a: [\"user_key\", \"bucketing_key\", [\"flag_set_name1\", \"flag_set_name2\"], %{}],\n      o: 23,\n      v: 1\n    }\n\n    iex> Message.get_treatments_by_flag_sets(\n    ...>   key: \"user_key\",\n    ...>   feature_names: [\"flag_set_name1\", \"flag_set_name2\"]\n    ...> )\n    %Message{a: [\"user_key\", nil, [\"flag_set_name1\", \"flag_set_name2\"], %{}], o: 23, v: 1}","ref":"Split.RPC.Message.html#get_treatments_by_flag_sets/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatments_with_config/1","doc":"Builds a message to get the treatments for multiple feature flags with configuration.","ref":"Split.RPC.Message.html#get_treatments_with_config/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatments_with_config/1","doc":"iex> Message.get_treatments_with_config(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_names: [\"feature_name1\", \"feature_name2\"]\n    ...> )\n    %Message{\n      a: [\"user_key\", \"bucketing_key\", [\"feature_name1\", \"feature_name2\"], %{}],\n      o: 20,\n      v: 1\n    }\n\n    iex> Message.get_treatments_with_config(\n    ...>   key: \"user_key\",\n    ...>   feature_names: [\"feature_name1\", \"feature_name2\"]\n    ...> )\n    %Message{\n      a: [\"user_key\", nil, [\"feature_name1\", \"feature_name2\"], %{}],\n      o: 20,\n      v: 1\n    }","ref":"Split.RPC.Message.html#get_treatments_with_config/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatments_with_config_by_flag_set/1","doc":"Builds a message to get the treatments for a flag set with configuration.","ref":"Split.RPC.Message.html#get_treatments_with_config_by_flag_set/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatments_with_config_by_flag_set/1","doc":"iex> Message.get_treatments_with_config_by_flag_set(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_name: \"flag_set_name\"\n    ...> )\n    %Message{\n      a: [\"user_key\", \"bucketing_key\", \"flag_set_name\", %{}],\n      o: 22,\n      v: 1\n    }\n\n    iex> Message.get_treatments_with_config_by_flag_set(\n    ...>   key: \"user_key\",\n    ...>   feature_name: \"flag_set_name\"\n    ...> )\n    %Message{\n      a: [\"user_key\", nil, \"flag_set_name\", %{}],\n      o: 22,\n      v: 1\n    }","ref":"Split.RPC.Message.html#get_treatments_with_config_by_flag_set/1-examples"},{"type":"function","title":"Split.RPC.Message.get_treatments_with_config_by_flag_sets/1","doc":"Builds a message to get the treatments for multiple flag sets with configuration.","ref":"Split.RPC.Message.html#get_treatments_with_config_by_flag_sets/1"},{"type":"function","title":"Examples - Split.RPC.Message.get_treatments_with_config_by_flag_sets/1","doc":"iex> Message.get_treatments_with_config_by_flag_sets(\n    ...>   key: %{:matching_key => \"user_key\", :bucketing_key => \"bucketing_key\"},\n    ...>   feature_names: [\"flag_set_name1\", \"flag_set_name2\"]\n    ...> )\n    %Message{\n      a: [\"user_key\", \"bucketing_key\", [\"flag_set_name1\", \"flag_set_name2\"], %{}],\n      o: 24,\n      v: 1\n    }\n\n    iex> Message.get_treatments_with_config_by_flag_sets(\n    ...>   key: \"user_key\",\n    ...>   feature_names: [\"flag_set_name1\", \"flag_set_name2\"]\n    ...> )\n    %Message{\n      a: [\"user_key\", nil, [\"flag_set_name1\", \"flag_set_name2\"], %{}],\n      o: 24,\n      v: 1\n    }","ref":"Split.RPC.Message.html#get_treatments_with_config_by_flag_sets/1-examples"},{"type":"function","title":"Split.RPC.Message.opcode_to_rpc_name/1","doc":"Converts an opcode to the corresponding RPC call name.","ref":"Split.RPC.Message.html#opcode_to_rpc_name/1"},{"type":"function","title":"Examples - Split.RPC.Message.opcode_to_rpc_name/1","doc":"iex> Message.opcode_to_rpc_name(@get_treatment_opcode)\n  :get_treatment\n\n  iex> Message.opcode_to_rpc_name(@get_treatment_with_config_opcode)\n  :get_treatment_with_config\n\n  iex> Message.opcode_to_rpc_name(@get_treatments_opcode)\n  :get_treatments\n\n  iex> Message.opcode_to_rpc_name(@get_treatments_with_config_opcode)\n  :get_treatments_with_config\n\n  iex> Message.opcode_to_rpc_name(@split_opcode)\n  :split\n\n  iex> Message.opcode_to_rpc_name(@splits_opcode)\n  :splits\n\n  iex> Message.opcode_to_rpc_name(@split_names_opcode)\n  :split_names\n\n  iex> Message.opcode_to_rpc_name(@track_opcode)\n  :track","ref":"Split.RPC.Message.html#opcode_to_rpc_name/1-examples"},{"type":"function","title":"Split.RPC.Message.register/0","doc":"Builds a message to register a client in splitd.","ref":"Split.RPC.Message.html#register/0"},{"type":"function","title":"Examples - Split.RPC.Message.register/0","doc":"iex> Message.register()\n    %Message{v: 1, o: 0, a: [\"123\", \"Splitd_Elixir-\", 1]}","ref":"Split.RPC.Message.html#register/0-examples"},{"type":"function","title":"Split.RPC.Message.split/1","doc":"Builds a message to return information about an specific split (feature flag).","ref":"Split.RPC.Message.html#split/1"},{"type":"function","title":"Examples - Split.RPC.Message.split/1","doc":"iex> Message.split(\"my_feature\")\n    %Message{v: 1, o: 161, a: [\"my_feature\"]}","ref":"Split.RPC.Message.html#split/1-examples"},{"type":"function","title":"Split.RPC.Message.split_names/0","doc":"Builds a message to return the names of all the splits (feature flags) currently available in splitd.","ref":"Split.RPC.Message.html#split_names/0"},{"type":"function","title":"Examples - Split.RPC.Message.split_names/0","doc":"iex> Message.split_names()\n    %Message{v: 1, o: 160, a: []}","ref":"Split.RPC.Message.html#split_names/0-examples"},{"type":"function","title":"Split.RPC.Message.splits/0","doc":"Builds a message to return information about all the splits (feature flags) currently available in splitd.","ref":"Split.RPC.Message.html#splits/0"},{"type":"function","title":"Examples - Split.RPC.Message.splits/0","doc":"iex> Message.splits()\n    %Message{v: 1, o: 162, a: []}","ref":"Split.RPC.Message.html#splits/0-examples"},{"type":"function","title":"Split.RPC.Message.track/5","doc":"Message that creates and event and sends it to splitd so that it’s queued and submitted to Split.io.","ref":"Split.RPC.Message.html#track/5"},{"type":"function","title":"Examples - Split.RPC.Message.track/5","doc":"iex> Message.track(\"user_key\", \"traffic_type\", \"my_event\", 1.5, %{foo: \"bar\"})\n    %Message{\n      v: 1,\n      o: 128,\n      a: [\"user_key\", \"traffic_type\", \"my_event\", 1.5, %{foo: \"bar\"}]\n    }\n\n    iex> Message.track(\"user_key\", \"traffic_type\", \"my_event\")\n    %Message{v: 1, o: 128, a: [\"user_key\", \"traffic_type\", \"my_event\", nil, %{}]}","ref":"Split.RPC.Message.html#track/5-examples"},{"type":"type","title":"Split.RPC.Message.get_treatment_args/0","doc":"","ref":"Split.RPC.Message.html#t:get_treatment_args/0"},{"type":"type","title":"Split.RPC.Message.get_treatments_args/0","doc":"","ref":"Split.RPC.Message.html#t:get_treatments_args/0"},{"type":"type","title":"Split.RPC.Message.opcode/0","doc":"","ref":"Split.RPC.Message.html#t:opcode/0"},{"type":"type","title":"Split.RPC.Message.protocol_version/0","doc":"","ref":"Split.RPC.Message.html#t:protocol_version/0"},{"type":"type","title":"Split.RPC.Message.t/0","doc":"","ref":"Split.RPC.Message.html#t:t/0"},{"type":"module","title":"Split.RPC.ResponseParser","doc":"Contains the functions to parse the response from the Splitd RPC calls.","ref":"Split.RPC.ResponseParser.html"},{"type":"function","title":"Split.RPC.ResponseParser.parse_response/3","doc":"Parses the response from the Splitd RPC calls.","ref":"Split.RPC.ResponseParser.html#parse_response/3"},{"type":"type","title":"Split.RPC.ResponseParser.splitd_response/0","doc":"","ref":"Split.RPC.ResponseParser.html#t:splitd_response/0"},{"type":"module","title":"Split.Sockets.Conn","doc":"Represents a TCP socket connection to the Splitd daemon.","ref":"Split.Sockets.Conn.html"},{"type":"function","title":"Split.Sockets.Conn.connect/1","doc":"","ref":"Split.Sockets.Conn.html#connect/1"},{"type":"function","title":"Split.Sockets.Conn.disconnect/1","doc":"","ref":"Split.Sockets.Conn.html#disconnect/1"},{"type":"function","title":"Split.Sockets.Conn.is_open?/1","doc":"","ref":"Split.Sockets.Conn.html#is_open?/1"},{"type":"function","title":"Split.Sockets.Conn.new/2","doc":"","ref":"Split.Sockets.Conn.html#new/2"},{"type":"function","title":"Split.Sockets.Conn.send_message/2","doc":"","ref":"Split.Sockets.Conn.html#send_message/2"},{"type":"function","title":"Split.Sockets.Conn.transfer_ownership/2","doc":"","ref":"Split.Sockets.Conn.html#transfer_ownership/2"},{"type":"type","title":"Split.Sockets.Conn.t/0","doc":"","ref":"Split.Sockets.Conn.html#t:t/0"},{"type":"module","title":"Split.Sockets.Pool","doc":"","ref":"Split.Sockets.Pool.html"},{"type":"function","title":"Split.Sockets.Pool.child_spec/1","doc":"","ref":"Split.Sockets.Pool.html#child_spec/1"},{"type":"function","title":"Split.Sockets.Pool.send_message/2","doc":"","ref":"Split.Sockets.Pool.html#send_message/2"},{"type":"function","title":"Split.Sockets.Pool.start_link/1","doc":"","ref":"Split.Sockets.Pool.html#start_link/1"},{"type":"module","title":"Split.Sockets.PoolMetrics","doc":"This module provides a way to store and update pool utilization metrics.","ref":"Split.Sockets.PoolMetrics.html"},{"type":"function","title":"Split.Sockets.PoolMetrics.get/1","doc":"","ref":"Split.Sockets.PoolMetrics.html#get/1"},{"type":"function","title":"Split.Sockets.PoolMetrics.init/2","doc":"","ref":"Split.Sockets.PoolMetrics.html#init/2"},{"type":"function","title":"Split.Sockets.PoolMetrics.update/2","doc":"","ref":"Split.Sockets.PoolMetrics.html#update/2"},{"type":"type","title":"Split.Sockets.PoolMetrics.t/0","doc":"","ref":"Split.Sockets.PoolMetrics.html#t:t/0"},{"type":"module","title":"Split.SplitView","doc":"","ref":"Split.SplitView.html"},{"type":"type","title":"Split.SplitView.t/0","doc":"","ref":"Split.SplitView.html#t:t/0"},{"type":"module","title":"Split.Supervisor","doc":"","ref":"Split.Supervisor.html"},{"type":"function","title":"Split.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Split.Supervisor.html#child_spec/1"},{"type":"function","title":"Split.Supervisor.init/1","doc":"","ref":"Split.Supervisor.html#init/1"},{"type":"function","title":"Split.Supervisor.start_link/1","doc":"","ref":"Split.Supervisor.html#start_link/1"},{"type":"module","title":"Split.Telemetry","doc":"Telemetry events for the Split SDK.\n\nThe following events are emitted by the Split SDK:","ref":"Split.Telemetry.html"},{"type":"module","title":"RPC Start - Split.Telemetry","doc":"`[:split, :rpc, :start]` - Emitted when an RPC call is started.\n\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n\n#### Metadata\n\n  * `rpc_call` - The RPC call name.","ref":"Split.Telemetry.html#module-rpc-start"},{"type":"module","title":"RPC Stop - Split.Telemetry","doc":"`[:split, :rpc, :stop]` - Emitted when an RPC call ends.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n  * `:duration` - Time taken from the RPC start event.\n\n#### Metadata\n\n  * `rpc_call` - The RPC call name.\n  * `response` - The response from the RPC call.\n  * `error` - The error message if the RPC call fails.","ref":"Split.Telemetry.html#module-rpc-stop"},{"type":"module","title":"RPC Fallback - Split.Telemetry","doc":"`[:split, :rpc, :fallback]` - Emitted when an RPC call falls back to the fallback mechanism.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n\n#### Metadata\n\n    * `rpc_call` - The RPC call name.\n    * `response` - The generated callback response from the RPC call.","ref":"Split.Telemetry.html#module-rpc-fallback"},{"type":"module","title":"Queue Start - Split.Telemetry","doc":"`[:split, :queue, :start]` - Executed before checking out a socket connection from the pool.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n\n#### Metadata\n\n  * `message` - The message being sent to the Splitd daemon.\n  * `pool_name` - The name of the pool being used.","ref":"Split.Telemetry.html#module-queue-start"},{"type":"module","title":"Queue Stop - Split.Telemetry","doc":"`[:split, :queue, :stop]` - Executed after checking out a socket connection from the pool.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n  * `:duration` - The time taken to check out a pool connection.\n\n#### Metadata\n\n  * `message` - The message being sent to the Splitd daemon.\n  * `pool_name` - The name of the pool being used.\n  * `error` - The error message if the RPC call fails.","ref":"Split.Telemetry.html#module-queue-stop"},{"type":"module","title":"Queue Exception - Split.Telemetry","doc":"`[:split, :queue, :exception]` - Executed when an exception occurs while checking out a socket connection from the pool.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n  * `:duration` - The time taken since queue start event before raising an exception.\n\n#### Metadata\n\n  * `message` - The message being sent to the Splitd daemon.\n  * `pool_name` - The name of the pool being used.\n  * `kind` - The exception type.\n  * `reason` - The exception reason.\n  * `stacktrace` - The exception stacktrace.","ref":"Split.Telemetry.html#module-queue-exception"},{"type":"module","title":"Connect Start - Split.Telemetry","doc":"`[:split, :connect, :start]` - Emitted when a connection to the Splitd daemon is established.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n\n#### Metadata\n\n  * `socket_path` - The path to the socket file.\n  * `pool_name` - The name of the pool being used.","ref":"Split.Telemetry.html#module-connect-start"},{"type":"module","title":"Connect Stop - Split.Telemetry","doc":"`[:split, :connect, :stop]` - Emitted when a connection to the Splitd daemon is established.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n  * `:duration` - The time taken to establish a connection.\n\n#### Metadata\n\n  * `socket_path` - The path to the socket file.\n  * `pool_name` - The name of the pool being used.\n  * `error` - The error message if the connection fails.","ref":"Split.Telemetry.html#module-connect-stop"},{"type":"module","title":"Send Start - Split.Telemetry","doc":"`[:split, :send, :start]` - Emitted before message is sent to the connected Splitd socket.\n\n#### Measurements\n\n   * `monotonic_time` - The time when the event was emitted.\n\n#### Metadata\n\n  * `request` - The message being sent to the Splitd daemon.","ref":"Split.Telemetry.html#module-send-start"},{"type":"module","title":"Send Stop - Split.Telemetry","doc":"`[:split, :send, :stop]` - Emitted when a message is sent to the connected Splitd socket.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n  * `:duration` - The time taken to send a message.\n\n#### Metadata\n\n  * `request` - The message being sent to the Splitd daemon.\n  * `error` - The error message if the message fails to send.","ref":"Split.Telemetry.html#module-send-stop"},{"type":"module","title":"Receive Start - Split.Telemetry","doc":"`[:split, :receive, :start]` - Emitted before receiving a message from the connected Splitd socket.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n\n#### Metadata\n\n  * `request` - The message being received from the Splitd daemon.","ref":"Split.Telemetry.html#module-receive-start"},{"type":"module","title":"Receive Stop - Split.Telemetry","doc":"`[:split, :receive, :stop]` - Emitted when a message is received from the connected Splitd socket.\n\n#### Measurements\n\n  * `monotonic_time` - The time when the event was emitted.\n  * `:duration` - The time taken to receive a message.\n\n#### Metadata\n\n  * `request` - The message being received from the Splitd daemon.\n  * `response` - The response received from the Splitd daemon.\n  * `error` - The error message if the message fails to receive.","ref":"Split.Telemetry.html#module-receive-stop"},{"type":"module","title":"Impression - Split.Telemetry","doc":"`[:split, :impression]` - Emitted when a treatment is assigned to a user. This is equivalent to an impression in the Split system.\n\n#### measurements:\n  * `impression` - A `%Split.Impression{}` struct containing the following fields:\n    * `key` - The user key.\n    * `feature` - The feature name.\n    * `treatment` - The treatment assigned to the user.\n    * `label` - The label assigned to the treatment.\n    * `change_number` - The change number of the treatment.\n    * `timestamp` - The timestamp of the treatment assignment.","ref":"Split.Telemetry.html#module-impression"},{"type":"function","title":"Split.Telemetry.exception/4","doc":"Emits a telemetry `exception` event.","ref":"Split.Telemetry.html#exception/4"},{"type":"function","title":"Split.Telemetry.monotonic_time/0","doc":"","ref":"Split.Telemetry.html#monotonic_time/0"},{"type":"function","title":"Split.Telemetry.send_impression/1","doc":"Emits a telemetry `impression` event when a Split treatment has been evaluated.","ref":"Split.Telemetry.html#send_impression/1"},{"type":"function","title":"Split.Telemetry.span/3","doc":"Wraps a function in a telemetry span.","ref":"Split.Telemetry.html#span/3"},{"type":"function","title":"Split.Telemetry.span_event/4","doc":"Emits a one-off telemetry event.","ref":"Split.Telemetry.html#span_event/4"},{"type":"function","title":"Split.Telemetry.start/3","doc":"Emits a `start` telemetry span.","ref":"Split.Telemetry.html#start/3"},{"type":"function","title":"Split.Telemetry.stop/3","doc":"Emits a telemetry `stop` event.","ref":"Split.Telemetry.html#stop/3"},{"type":"opaque","title":"Split.Telemetry.t/0","doc":"","ref":"Split.Telemetry.html#t:t/0"},{"type":"module","title":"Split.TreatmentWithConfig","doc":"","ref":"Split.TreatmentWithConfig.html"},{"type":"type","title":"Split.TreatmentWithConfig.t/0","doc":"","ref":"Split.TreatmentWithConfig.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}